import "./chunk-E2PHHEDL.mjs";
import fs from "node:fs";
import ejs from "ejs";
import { marked } from "marked";
const bootstrapClassSeverityMap = {
  critical: "danger",
  high: "warning",
  moderate: "secondary",
  low: "primary",
  info: "info"
};
const severitySortPriority = Object.keys(bootstrapClassSeverityMap);
function parseAdvisory(advisory) {
  const vulnerabilities = {};
  advisory.findings.forEach((finding) => {
    const { version } = finding;
    const key = `${advisory.module_name}@${version}-${advisory.vulnerable_versions}-${advisory.created}.${advisory.cwe}`;
    if (!(key in vulnerabilities)) {
      vulnerabilities[key] = {
        ...advisory,
        key,
        version,
        paths: finding.paths
      };
    } else {
      vulnerabilities[key].paths = [...vulnerabilities[key].paths, ...finding.paths];
    }
  });
  Object.entries(vulnerabilities).forEach(([key, vulnerability]) => {
    vulnerabilities[key].paths = Array.from(new Set(vulnerability.paths));
  });
  return Object.values(vulnerabilities);
}
async function generateReport(vulnerabilities, summary, options) {
  vulnerabilities.sort(
    (left, right) => severitySortPriority.indexOf(left.severity) - severitySortPriority.indexOf(right.severity)
  );
  const report = await renderReport(
    {
      reportDate: /* @__PURE__ */ new Date(),
      vulnerabilities,
      summary: {
        vulnerabilities: Object.values(summary.vulnerabilities).reduce((sum, value) => sum + value, 0),
        totalDependencies: summary.totalDependencies
      }
    },
    options.template
  );
  await writeReport(options.output, report);
  if (vulnerabilities.length > 0) {
    console.info(`Found ${vulnerabilities.length} vulnerabilities. Report is saved in "${options.output}"`);
    if (options.fatalExitCode) {
      return process.exit(1);
    }
  } else {
    console.info("Congrats!!! No vulnerabilities found.");
  }
  return process.exit(0);
}
async function renderReport(data, template) {
  const htmlTemplate = await fs.promises.readFile(template, "utf8");
  return ejs.render(htmlTemplate, {
    data,
    formatDate: (dateStr) => new Date(dateStr).toLocaleString(),
    severityClass: (severity) => bootstrapClassSeverityMap[severity],
    markdown: marked
  });
}
async function writeReport(outputPath, report) {
  await fs.promises.writeFile(outputPath, report, { encoding: "utf8" });
}
function bailWithError(message, error, isFatalExitCode) {
  console.error(`${message}
`, error);
  if (isFatalExitCode) {
    return process.exit(1);
  }
  return process.exit(0);
}
export {
  bailWithError,
  generateReport,
  parseAdvisory,
  renderReport,
  writeReport
};
